smartcard.CardType.AnyCardType

# ``smartcard`.`CardType`.`AnyCardType``

class documentation

`class AnyCardType(CardType):`

View In Hierarchy

The AnyCardType matches any card.

Method | `__init__` | CardType constructor.
Method | `matches` | Always returns true, i.e. AnyCardType matches any card.

def __init__(self):
overrides `smartcard.CardType.CardType.__init__`

CardType constructor.

def matches(self, atr, reader=None):
overrides `smartcard.CardType.CardType.matches`

Always returns true, i.e. AnyCardType matches any card.

Parameters
atr | the atr to chek for matching
reader | the reader (optional); default is None